Note that this installation description is for release !

# Quick installation

Notes:

- This simple install receipt requires that the machine has Internet (proxy) access to load packages from PyPI repository.
- Some C wrapper modules have to be compiled. So you have to install a C compiler and build tools for your particular OS.
- Also look for platform-specific instructions.

Install in a Python virtual environment:

    python3 -m venv /opt/web2ldap
    /opt/web2ldap/bin/pip3 install --find-links https://www.web2ldap.de/download.html web2ldap

Start simple stand-alone web server by default listening on localhost, port 1760:

    /opt/web2ldap/bin/web2ldap 127.0.0.1 1760

For remote access to this stand-alone instance you have to explicitly allow access from remote IP addresses by editing configuration option access_allowed in file `etc/web2ldap/web2ldapcnf/__init__.py`.

For serious use you should use a HTTPS-enabled web server as frontend. See directories `etc/apache2/` and `etc/uwsgi/` in source distribution for web server integration examples.

# Upgrade instructions

If you've customized web2ldap configuration backup your local config changes first:

    cp -av /opt/web2ldap/etc/web2ldap /path/to/backupdir/

Then install the web2ldap upgrade (without necessarily upgrading other modules) like this:

    /opt/web2ldap/bin/pip3 install --upgrade --upgrade-strategy only-if-needed --find-links https://www.web2ldap.de/download.html web2ldap

Restore your customized web2ldap configuration e.g. from backup or via config management.

# Platform-specific instructions

- openSUSE and SLE
- Running in a container
- FreeBSD port
- OpenBSD port (see also openports.se)